Type: Package
Package: autosync
Title: 'Automerge' Sync Server and Client
Version: 0.1.0
Authors@R: c(
    person("Charlie", "Gao", , "charlie.gao@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-0750-061X")),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: A WebSocket-based implementation of the 'automerge-repo'
    synchronization protocol used by 'sync.automerge.org'. Acts as a sync
    server, enabling 'R' to serve as a synchronization hub for 'Automerge'
    clients in 'JavaScript', 'Rust', and other languages, and as a client
    for fetching, editing, and synchronizing documents hosted on remote
    servers.
License: MIT + file LICENSE
URL: https://posit-dev.github.io/autosync/,
        https://github.com/posit-dev/autosync
BugReports: https://github.com/posit-dev/autosync/issues
Depends: R (>= 4.4)
Imports: automerge (>= 0.4.0), httr2 (>= 1.2.3), jose, later, nanonext
        (>= 1.8.1), promises, secretbase (>= 1.3.0)
Suggests: openssl, testthat (>= 3.0.0)
Config/Needs/website: tidyverse/tidytemplate
Config/roxygen2/markdown: TRUE
Config/roxygen2/version: 8.0.0.9000
Config/testthat/edition: 3
Encoding: UTF-8
NeedsCompilation: no
Packaged: 2026-06-30 20:04:11 UTC; cg334
Author: Charlie Gao [aut, cre] (ORCID: <https://orcid.org/0000-0002-0750-061X>),
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Charlie Gao <charlie.gao@posit.co>
Repository: CRAN
Date/Publication: 2026-07-06 14:00:10 UTC
