% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auth.R
\name{fetch_jwks}
\alias{fetch_jwks}
\title{Fetch and parse a JWKS endpoint}
\usage{
fetch_jwks(jwks_uri)
}
\arguments{
\item{jwks_uri}{URL of the JWKS endpoint.}
}
\value{
List with \code{keys} (named list of jose key objects by kid) and
\code{expiry} (POSIXct when the cache should be refreshed).
}
\description{
Fetch and parse a JWKS endpoint
}
\keyword{internal}
