% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{generate_document_id}
\alias{generate_document_id}
\title{Generate a new document ID}
\usage{
generate_document_id()
}
\value{
Character string (Base58Check encoded).
}
\description{
Creates a new unique document ID compatible with automerge-repo.
The ID is a 16-byte random value encoded with Base58Check.
}
\examples{
generate_document_id()

}
