% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/auth.R
\name{oidc_issuer}
\alias{oidc_issuer}
\title{Default OIDC issuer URL}
\usage{
oidc_issuer()
}
\value{
Character string, the OIDC issuer URL.
}
\description{
Returns the \code{OIDC_ISSUER} environment variable if set and non-empty,
otherwise falls back to Google (\code{"https://accounts.google.com"}).
}
\keyword{internal}
