% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/server.R
\name{get_document}
\alias{get_document}
\title{Get a document from the server}
\usage{
get_document(server, doc_id)
}
\arguments{
\item{server}{An autosync_server object.}

\item{doc_id}{Document ID string.}
}
\value{
Automerge document object, or NULL if not found.
}
\description{
Retrieves an Automerge document by its ID.
}
\examples{
\dontshow{if (interactive()) withAutoprint(\{ # examplesIf}
server <- sync_server()
doc_id <- create_document(server)
get_document(server, doc_id)
server$close()
\dontshow{\}) # examplesIf}
}
